@@ -40,15 +40,15 @@ def get_status(index):
 
 def show_status(data):
     status = data
-    img_tag = '<img src="%s" title="%s"/>'
+    img_tag = '<img src="{img}" title="{label}" class="status-icon" />{label}'
     if status == 'CRITICAL':
-        return img_tag % (constants.CRITICAL_ICON, status)
+        return img_tag.format(img=constants.CRITICAL_ICON, label=status)
     if status in ('LOW', 'MEDIUM', 'HIGH'):
-        return img_tag % (constants.WARNING_ICON, status)
+        return img_tag.format(img=constants.WARNING_ICON, label=status)
     if status == 'OK':
-        return img_tag % (constants.OK_ICON, status)
+        return img_tag.format(img=constants.OK_ICON, label=status)
     if status == 'UNKNOWN' or status == 'UNDETERMINED':
-        return img_tag % (constants.UNKNOWN_ICON, status)
+        return img_tag.format(img=constants.UNKNOWN_ICON, label=status)
     return status
 
 
@@ -75,7 +75,12 @@ def show_def_severity(data):
 
 def show_metric_dimensions(data):
     if len(data['metrics']) > 1:
-        return _('Multiple metrics')
+        commondimensions = data['metrics'][0]['dimensions']
+        for metric in data['metrics'][1:]:
+            for k in commondimensions.keys():
+                if k not in metric['dimensions'].keys() or commondimensions[k] != metric['dimensions'][k]:
+                    del commondimensions[k]
+        return ','.join(["%s=%s" % (n, v) for n,v in commondimensions.items()])
     else:
         return ','.join(["%s=%s" % (n, v) for n,v in data['metrics'][0]['dimensions'].items()])
 
@@ -181,7 +186,7 @@ class AlarmsFilterAction(tables.FilterAction):
         """Naive case-insensitive search."""
         q = filter_string.lower()
         return [alarm for alarm in alarms
-                if q in alarm.name.lower()]
+                if q in alarm['metrics'][0]['name'].lower()]
 
 
 class AlarmsTable(tables.DataTable):
